@@ -39,7 +39,7 @@ use Symbol ();
 use File::Basename ();
 
 
-$Net::Daemon::Test::VERSION = '0.02';
+$Net::Daemon::Test::VERSION = '0.03';
 @Net::Daemon::Test::ISA = qw(Net::Daemon);
 
 
@@ -289,7 +289,7 @@ sub Child ($$@) {
 	print "Starting process: proc = $path, args = ", join(" ", @_), "\n";
 	if (!&Win32::Process::Create($pid, $path,
  				     join(" ", @_), 0,
- 				     Win32::Process::NORMAL_PRIORITY_CLASS(),
+                                     Win32::Process::DETACHED_PROCESS(),
  				     ".")) {
  	    die "Cannot create child process: "
  		. Win32::FormatMessage(Win32::GetLastError());
